@@ -24,12 +24,15 @@
 import types
 import gettext
 
+
 from duplicity import log
 from duplicity import file_naming
 from duplicity import path
+from duplicity import util
 from duplicity import dup_time
 from duplicity import globals
 from duplicity import manifest
+from duplicity import util
 from duplicity.gpg import GPGError
 
 class CollectionsError(Exception):
@@ -144,26 +147,22 @@ class BackupSet:
         try:
             self.backend.delete(rfn)
         except Exception:
-            log.Debug("BackupSet.delete: missing %s" % rfn)
+            log.Debug(_("BackupSet.delete: missing %s") % map(util.ufn, rfn))
             pass
         for lfn in globals.archive_dir.listdir():
             pr = file_naming.parse(lfn)
             if (pr
                 and pr.time == self.time
                 and pr.start_time == self.start_time
-                and pr.end_time == self.end_time
-                and pr.type != "new-sig" ):
-                # do not remove new sigs from the cache:
-                # they aren't removed from the remote archive,
-                # and subsequent backups will have to resync
-                # which is bad if running non-interactive with encrypt-key
+                and pr.end_time == self.end_time):
                 try:
                     globals.archive_dir.append(lfn).delete()
                 except Exception:
-                    log.Debug("BackupSet.delete: missing %s" % lfn)
+                    log.Debug(_("BackupSet.delete: missing %s") % map(util.ufn, lfn))
                     pass
+        util.release_lockfile()
 
-    def __str__(self):
+    def __unicode__(self):
         """
         For now just list files in set
         """
@@ -171,7 +170,7 @@ class BackupSet:
         if self.remote_manifest_name:
             filelist.append(self.remote_manifest_name)
         filelist.extend(self.volume_name_dict.values())
-        return "[%s]" % ", ".join(filelist)
+        return u"[%s]" % u", ".join(map(util.ufn, filelist))
 
     def get_timestr(self):
         """
@@ -326,13 +325,13 @@ class BackupChain:
         assert self.end_time
         return True
 
-    def delete(self):
+    def delete(self, keep_full=False):
         """
         Delete all sets in chain, in reverse order
         """
         for i in range(len(self.incset_list)-1, -1, -1):
             self.incset_list[i].delete()
-        if self.fullset:
+        if self.fullset and not keep_full:
             self.fullset.delete()
 
     def get_sets_at_time(self, time):
@@ -530,7 +529,7 @@ class SignatureChain:
             filename_to_fileobj = self.backend.get_fileobj_read
         return map(filename_to_fileobj, self.get_filenames(time))
 
-    def delete(self):
+    def delete(self, keep_full=False):
         """
         Remove all files in signature set
         """
@@ -538,12 +537,14 @@ class SignatureChain:
         if self.archive_dir:
             for i in range(len(self.inclist)-1, -1, -1):
                 self.archive_dir.append(self.inclist[i]).delete()
-            self.archive_dir.append(self.fullsig).delete()
+            if not keep_full:
+                self.archive_dir.append(self.fullsig).delete()
         else:
             assert self.backend
             inclist_copy = self.inclist[:]
             inclist_copy.reverse()
-            inclist_copy.append(self.fullsig)
+            if not keep_full:
+                inclist_copy.append(self.fullsig)
             self.backend.delete(inclist_copy)
 
     def get_filenames(self, time = None):
@@ -614,42 +615,42 @@ class CollectionsStatus:
 
         return l
 
-    def __str__(self):
+    def __unicode__(self):
         """
         Return string summary of the collection
         """
         l = [_("Collection Status"),
-             "-----------------",
+             u"-----------------",
              _("Connecting with backend: %s") %
              (self.backend.__class__.__name__,),
-             _("Archive dir: %s") % (self.archive_dir.name,)]
+             _("Archive dir: %s") % (util.ufn(self.archive_dir.name),)]
 
         l.append("\n" +
-                 gettext.ngettext("Found %d secondary backup chain.",
-                                  "Found %d secondary backup chains.",
-                                  len(self.other_backup_chains))
+                 ngettext("Found %d secondary backup chain.",
+                          "Found %d secondary backup chains.",
+                          len(self.other_backup_chains))
                  % len(self.other_backup_chains))
         for i in range(len(self.other_backup_chains)):
             l.append(_("Secondary chain %d of %d:") %
                      (i+1, len(self.other_backup_chains)))
-            l.append(str(self.other_backup_chains[i]))
+            l.append(unicode(self.other_backup_chains[i]))
             l.append("")
 
         if self.matched_chain_pair:
             l.append("\n" + _("Found primary backup chain with matching "
                      "signature chain:"))
-            l.append(str(self.matched_chain_pair[1]))
+            l.append(unicode(self.matched_chain_pair[1]))
         else:
             l.append(_("No backup chains with active signatures found"))
 
         if self.orphaned_backup_sets or self.incomplete_backup_sets:
-            l.append(gettext.ngettext("Also found %d backup set not part of any chain,",
-                                      "Also found %d backup sets not part of any chain,",
-                                      len(self.orphaned_backup_sets))
+            l.append(ngettext("Also found %d backup set not part of any chain,",
+                              "Also found %d backup sets not part of any chain,",
+                              len(self.orphaned_backup_sets))
                      % (len(self.orphaned_backup_sets),))
-            l.append(gettext.ngettext("and %d incomplete backup set.",
-                                      "and %d incomplete backup sets.",
-                                      len(self.incomplete_backup_sets))
+            l.append(ngettext("and %d incomplete backup set.",
+                              "and %d incomplete backup sets.",
+                              len(self.incomplete_backup_sets))
                      % (len(self.incomplete_backup_sets),))
             # TRANSL: "cleanup" is a hard-coded command, so do not translate it
             l.append(_('These may be deleted by running duplicity with the '
@@ -657,7 +658,7 @@ class CollectionsStatus:
         else:
             l.append(_("No orphaned or incomplete backup sets found."))
 
-        return "\n".join(l)
+        return u"\n".join(l)
 
     def set_values(self, sig_chain_warning = 1):
         """
@@ -671,16 +672,16 @@ class CollectionsStatus:
 
         # get remote filename list
         backend_filename_list = self.backend.list()
-        log.Debug(gettext.ngettext("%d file exists on backend",
-                                   "%d files exist on backend",
-                                   len(backend_filename_list)) %
+        log.Debug(ngettext("%d file exists on backend",
+                           "%d files exist on backend",
+                           len(backend_filename_list)) %
                   len(backend_filename_list))
 
         # get local filename list
         local_filename_list = self.archive_dir.listdir()
-        log.Debug(gettext.ngettext("%d file exists in cache",
-                                   "%d files exist in cache",
-                                   len(local_filename_list)) %
+        log.Debug(ngettext("%d file exists in cache",
+                           "%d files exist in cache",
+                           len(local_filename_list)) %
                   len(local_filename_list))
 
         # check for partial backups
@@ -753,21 +754,21 @@ class CollectionsStatus:
         assert self.values_set
 
         if self.local_orphaned_sig_names:
-            log.Warn(gettext.ngettext("Warning, found the following local orphaned "
-                                      "signature file:",
-                                      "Warning, found the following local orphaned "
-                                      "signature files:",
-                                      len(self.local_orphaned_sig_names))
-                     + "\n" + "\n".join(self.local_orphaned_sig_names),
+            log.Warn(ngettext("Warning, found the following local orphaned "
+                              "signature file:",
+                              "Warning, found the following local orphaned "
+                              "signature files:",
+                              len(self.local_orphaned_sig_names))
+                     + u"\n" + u"\n".join(map(util.ufn, self.local_orphaned_sig_names)),
                      log.WarningCode.orphaned_sig)
 
         if self.remote_orphaned_sig_names:
-            log.Warn(gettext.ngettext("Warning, found the following remote orphaned "
-                                      "signature file:",
-                                      "Warning, found the following remote orphaned "
-                                      "signature files:",
-                                      len(self.remote_orphaned_sig_names))
-                     + "\n" + "\n".join(self.remote_orphaned_sig_names),
+            log.Warn(ngettext("Warning, found the following remote orphaned "
+                              "signature file:",
+                              "Warning, found the following remote orphaned "
+                              "signature files:",
+                              len(self.remote_orphaned_sig_names))
+                     + u"\n" + u"\n".join(map(util.ufn, self.remote_orphaned_sig_names)),
                      log.WarningCode.orphaned_sig)
 
         if self.all_sig_chains and sig_chain_warning and not self.matched_chain_pair:
@@ -779,13 +780,12 @@ class CollectionsStatus:
                        "from aborted session"), log.WarningCode.incomplete_backup)
 
         if self.orphaned_backup_sets:
-            log.Warn(gettext.ngettext("Warning, found the following orphaned "
-                                      "backup file:",
-                                      "Warning, found the following orphaned "
-                                      "backup files:",
-                                      len(self.orphaned_backup_sets))
-                     + "\n" + "\n".join(map(lambda x: str(x),
-                                            self.orphaned_backup_sets)),
+            log.Warn(ngettext("Warning, found the following orphaned "
+                              "backup file:",
+                              "Warning, found the following orphaned "
+                              "backup files:",
+                              len(self.orphaned_backup_sets))
+                     + u"\n" + u"\n".join(map(unicode, self.orphaned_backup_sets)),
                      log.WarningCode.orphaned_backup)
 
     def get_backup_chains(self, filename_list):
@@ -798,7 +798,7 @@ class CollectionsStatus:
         missing files.
         """
         log.Debug(_("Extracting backup chains from list of files: %s")
-                  % filename_list)
+                  % map(util.ufn, filename_list))
         # First put filenames in set form
         sets = []
         def add_to_sets(filename):
@@ -807,15 +807,15 @@ class CollectionsStatus:
             """
             for set in sets:
                 if set.add_filename(filename):
-                    log.Debug(_("File %s is part of known set") % (filename,))
+                    log.Debug(_("File %s is part of known set") % (util.ufn(filename),))
                     break
             else:
-                log.Debug(_("File %s is not part of a known set; creating new set") % (filename,))
+                log.Debug(_("File %s is not part of a known set; creating new set") % (util.ufn(filename),))
                 new_set = BackupSet(self.backend)
                 if new_set.add_filename(filename):
                     sets.append(new_set)
                 else:
-                    log.Debug(_("Ignoring file (rejected by backup set) '%s'") % filename)
+                    log.Debug(_("Ignoring file (rejected by backup set) '%s'") % util.ufn(filename))
         map(add_to_sets, filename_list)
         sets, incomplete_sets = self.get_sorted_sets(sets)
 
@@ -1009,8 +1009,6 @@ class CollectionsStatus:
             if self.matched_chain_pair:
                 matched_sig_chain = self.matched_chain_pair[0]
                 for sig_chain in self.all_sig_chains:
-                    print sig_chain.start_time, matched_sig_chain.start_time,
-                    print sig_chain.end_time, matched_sig_chain.end_time
                     if (sig_chain.start_time == matched_sig_chain.start_time and
                         sig_chain.end_time == matched_sig_chain.end_time):
                         old_sig_chains.remove(sig_chain)
@@ -1032,10 +1030,43 @@ class CollectionsStatus:
 
     def get_chains_older_than(self, t):
         """
-        Return a list of chains older than time t
+        Returns a list of backup chains older than the given time t
+
+        All of the times will be associated with an intact chain.
+        Furthermore, none of the times will be of a chain which a newer
+        set may depend on.  For instance, if set A is a full set older
+        than t, and set B is an incremental based on A which is newer
+        than t, then the time of set A will not be returned.
         """
         assert self.values_set
-        return filter(lambda c: c.end_time < t, self.all_backup_chains)
+        old_chains = []
+        for chain in self.all_backup_chains:
+            if chain.end_time < t and (
+                not self.matched_chain_pair or
+                chain is not self.matched_chain_pair[1]):
+                # don't delete the active (matched) chain
+                old_chains.append(chain)
+        return old_chains
+
+    def get_signature_chains_older_than(self, t):
+        """
+        Returns a list of signature chains older than the given time t
+
+        All of the times will be associated with an intact chain.
+        Furthermore, none of the times will be of a chain which a newer
+        set may depend on.  For instance, if set A is a full set older
+        than t, and set B is an incremental based on A which is newer
+        than t, then the time of set A will not be returned.
+        """
+        assert self.values_set
+        old_chains = []
+        for chain in self.all_sig_chains:
+            if chain.end_time < t and (
+                not self.matched_chain_pair or
+                chain is not self.matched_chain_pair[0]):
+                # don't delete the active (matched) chain
+                old_chains.append(chain)
+        return old_chains
 
     def get_last_full_backup_time(self):
         """
@@ -1098,10 +1129,7 @@ class CollectionsStatus:
         """
         old_sets = []
         for chain in self.get_chains_older_than(t):
-            if (not self.matched_chain_pair or
-                chain is not self.matched_chain_pair[1]):
-                # don't delete the active (matched) chain
-                old_sets.extend(chain.get_all_sets())
+            old_sets.extend(chain.get_all_sets())
         return self.sort_sets(old_sets)
 
     def get_older_than_required(self, t):
