@@ -21,10 +21,12 @@
 
 """Store global configuration information"""
 
-import socket, os
+import os
+import socket
+
 
 # The current version of duplicity
-version = "0.6.20"
+version = "0.6.23"
 
 # Default file_prefix value
 file_prefix = ""
@@ -75,6 +77,9 @@ gpg_profile = None
 # Options to pass to gpg
 gpg_options = ''
 
+# Maximum file blocksize
+max_blocksize = 2048L
+
 # If true, filelists and directory statistics will be split on
 # nulls instead of newlines.
 null_separator = None
@@ -90,6 +95,9 @@ pydevd = False
 # windows machines.
 time_separator = ":"
 
+# Global lockfile used to manage concurrency
+lockfile = None
+
 # If this is true, only warn and don't raise fatal error when backup
 # source directory doesn't match previous backup source directory.
 allow_source_mismatch = None
@@ -135,7 +143,7 @@ encryption = True
 compression = True
 
 # volume size. default 25M
-volsize = 25*1024*1024
+volsize = 25 * 1024 * 1024
 
 # Working directory for the tempfile module. Defaults to /tmp on most systems.
 temproot = None
@@ -178,10 +186,10 @@ s3_use_multiprocessing = False
 # Chunk size used for S3 multipart uploads.The number of parallel uploads to
 # S3 be given by chunk size / volume size. Use this to maximize the use of
 # your bandwidth. Defaults to 25MB
-s3_multipart_chunk_size = 25*1024*1024
+s3_multipart_chunk_size = 25 * 1024 * 1024
 
 # Minimum chunk size accepted by S3
-s3_multipart_minimum_chunk_size = 5*1024*1024
+s3_multipart_minimum_chunk_size = 5 * 1024 * 1024
 
 # Whether to use the full email address as the user name when
 # logging into an imap server. If false just the user name
@@ -214,6 +222,13 @@ ssh_options = ""
 # whether to use scp for put/get, sftp is default
 use_scp = False
 
+# default cf backend is pyrax
+cf_backend = "pyrax"
+
+# HTTPS ssl optons (currently only webdav)
+ssl_cacert_file = None
+ssl_no_check_certificate = False
+
 # user added rsync options
 rsync_options = ""
 
@@ -237,3 +252,14 @@ extra_clean = False
 
 # Renames (--rename)
 rename = {}
+
+# enable data comparison on verify runs
+compare_data = False
+
+# When selected, triggers a dry-run before a full or incremental to compute
+# changes, then runs the real operation and keeps track of the real progress
+progress = False
+
+# Controls the upload progress messages refresh rate. Default: update each
+# 3 seconds
+progress_rate = 3
