@@ -26,7 +26,7 @@ associates stat information with filenames
 
 """
 
-import stat, errno, socket, time, re, gzip, pwd, grp
+import stat, errno, socket, time, re, gzip
 
 from duplicity import tarfile
 from duplicity import file_naming
@@ -36,6 +36,7 @@ from duplicity import util
 from duplicity import librsync
 from duplicity import log #@UnusedImport
 from duplicity import dup_time
+from duplicity import cached_ops
 from duplicity.lazy import * #@UnusedWildImport
 
 _copy_blocksize = 64 * 1024
@@ -80,8 +81,8 @@ class ROPath:
         elif stat.S_ISFIFO(st_mode):
             self.type = "fifo"
         elif stat.S_ISSOCK(st_mode):
-            raise PathException(self.get_relative_path() +
-                                "is a socket, unsupported by tar")
+            raise PathException(util.ufn(self.get_relative_path()) +
+                                u"is a socket, unsupported by tar")
             self.type = "sock"
         elif stat.S_ISCHR(st_mode):
             self.type = "chr"
@@ -206,20 +207,20 @@ class ROPath:
         try:
             if globals.numeric_owner:
                 raise KeyError
-            self.stat.st_uid = pwd.getpwnam(tarinfo.uname)[2]
+            self.stat.st_uid = cached_ops.getpwnam(tarinfo.uname)[2]
         except KeyError:
             self.stat.st_uid = tarinfo.uid
         try:
             if globals.numeric_owner:
                 raise KeyError
-            self.stat.st_gid = grp.getgrnam(tarinfo.gname)[2]
+            self.stat.st_gid = cached_ops.getgrnam(tarinfo.gname)[2]
         except KeyError:
             self.stat.st_gid = tarinfo.gid
 
         self.stat.st_mtime = int(tarinfo.mtime)
         if self.stat.st_mtime < 0:
             log.Warn(_("Warning: %s has negative mtime, treating as 0.")
-                     % (tarinfo.name,))
+                     % (util.ufn(tarinfo.name)))
             self.stat.st_mtime = 0
         self.stat.st_size = tarinfo.size
 
@@ -278,17 +279,17 @@ class ROPath:
             ti.uid, ti.gid = self.stat.st_uid, self.stat.st_gid
             if self.stat.st_mtime < 0:
                 log.Warn(_("Warning: %s has negative mtime, treating as 0.")
-                         % (self.get_relative_path(),))
+                         % (util.ufn(self.get_relative_path())))
                 ti.mtime = 0
             else:
                 ti.mtime = int(self.stat.st_mtime)
 
             try:
-                ti.uname = pwd.getpwuid(ti.uid)[0]
+                ti.uname = cached_ops.getpwuid(ti.uid)[0]
             except KeyError:
                 ti.uname = ''
             try:
-                ti.gname = grp.getgrgid(ti.gid)[0]
+                ti.gname = cached_ops.getgrgid(ti.gid)[0]
             except KeyError:
                 ti.gname = ''
 
@@ -342,8 +343,8 @@ class ROPath:
 
         """
         def log_diff(log_string):
-            log_str = _("Difference found:") + " " + log_string
-            log.Notice(log_str % (self.get_relative_path(),))
+            log_str = _("Difference found:") + u" " + log_string
+            log.Notice(log_str % (util.ufn(self.get_relative_path())))
 
         if not self.type and not other.type:
             return 1
@@ -458,9 +459,9 @@ class ROPath:
             other.stat = stat
             other.mode = self.mode
 
-    def __repr__(self):
+    def __unicode__(self):
         """Return string representation"""
-        return "(%s %s)" % (self.index, self.type)
+        return u"(%s %s)" % (util.uindex(self.index), self.type)
 
 
 class Path(ROPath):
@@ -550,17 +551,17 @@ class Path(ROPath):
 
     def mkdir(self):
         """Make directory(s) at specified path"""
-        log.Info(_("Making directory %s") % (self.name,))
+        log.Info(_("Making directory %s") % util.ufn(self.name))
         try:
             os.makedirs(self.name)
         except OSError:
             if (not globals.force):
-                raise PathException("Error creating directory %s" % (self.name,), 7)
+                raise PathException("Error creating directory %s" % util.ufn(self.name), 7)
         self.setdata()
 
     def delete(self):
         """Remove this file"""
-        log.Info(_("Deleting %s") % (self.name,))
+        log.Info(_("Deleting %s") % util.ufn(self.name))
         if self.isdir():
             util.ignore_missing(os.rmdir, self.name)
         else:
@@ -569,14 +570,14 @@ class Path(ROPath):
 
     def touch(self):
         """Open the file, write 0 bytes, close"""
-        log.Info(_("Touching %s") % (self.name,))
+        log.Info(_("Touching %s") % util.ufn(self.name))
         fp = self.open("wb")
         fp.close()
 
     def deltree(self):
         """Remove self by recursively deleting files under it"""
         from duplicity import selection # todo: avoid circ. dep. issue
-        log.Info(_("Deleting tree %s") % (self.name,))
+        log.Info(_("Deleting tree %s") % util.ufn(self.name))
         itr = IterTreeReducer(PathDeleter, [])
         for path in selection.Select(self).set_iter():
             itr(path.index, path)
@@ -643,7 +644,7 @@ class Path(ROPath):
                 return temp_path
             _tmp_path_counter += 1
             assert _tmp_path_counter < 10000, \
-                   "Warning too many temp files created for " + self.name
+                   u"Warning too many temp files created for " + util.ufn(self.name)
 
     def compare_recursive(self, other, verbose = None):
         """Compare self to other Path, descending down directories"""
